/**
 * Copyright (c) 2024 Dominic Masters
 * 
 * This software is released under the MIT License.
 * https://opensource.org/licenses/MIT
 */

#pragma once
#include "animationitem.h"

#define ANIMATION_ITEM_COUNT_MAX 64

typedef struct _animation_t {
  float_t time;
  bool_t loop;

  float_t duration;
  animationitem_t items[ANIMATION_ITEM_COUNT_MAX];
  uint8_t itemCount;
} animation_t;

/**
 * Initializes an animation.
 * @param anim The animation to initialize.
 */
void animationInit(animation_t *anim);

/**
 * Updates an animation.
 * @param anim The animation to update.
 * @param delta The time since the last update.
 */
void animationUpdate(animation_t *anim, const float_t delta);

/**
 * Returns the total duration of the animation.
 * 
 * @param anim The animation to get the duration of.
 * @return The total duration of the animation.
 */
float_t animationDurationGet(const animation_t *anim);