/**
 * Copyright (c) 2024 Dominic Masters
 * 
 * This software is released under the MIT License.
 * https://opensource.org/licenses/MIT
 */

#include "drawshape.h"
#include "assert/assert.h"
#include "util/memory.h"

void drawClear(
  const char_t c,
  const uint8_t color
) {
  memorySet(FRAME_BUFFER, c, FRAME_HEIGHT * FRAME_WIDTH);
  memorySet(FRAME_COLOR, color, FRAME_HEIGHT * FRAME_WIDTH);
}

void drawBox(
  const uint16_t x,
  const uint16_t y,
  const uint16_t width,
  const uint16_t height,
  const char_t c,
  const uint8_t color
) {
  assertTrue(x < FRAME_WIDTH, "Box is too far right.");
  assertTrue(y < FRAME_HEIGHT, "Box is too far down.");
  if(width == 0 || height == 0) return;
  assertTrue(x + width <= FRAME_WIDTH, "Box is too wide.");
  assertTrue(y + height <= FRAME_HEIGHT, "Box is too tall.");

  if(width == FRAME_WIDTH) {
    memorySet(&FRAME_BUFFER[y * FRAME_WIDTH + x], c, height * width);
    memorySet(&FRAME_COLOR[y * FRAME_WIDTH + x], color, height * width);
    return;
  }

  for(uint16_t iy = 0; iy < height; iy++) {
    memorySet(&FRAME_BUFFER[(y + iy) * FRAME_WIDTH + x], c, width);
    memorySet(&FRAME_COLOR[(y + iy) * FRAME_WIDTH + x], color, width);
  }
}
