/**
 * Copyright (c) 2024 Dominic Masters
 * 
 * This software is released under the MIT License.
 * https://opensource.org/licenses/MIT
 */

#include "drawtext.h"
#include "assert/assert.h"
#include "util/math.h"

void drawText(
  const char_t *text,
  const size_t len,
  const uint16_t x,
  const uint16_t y,
  const uint8_t color
) {
  if(len == 0) return;
  size_t rLen = mathMin(len, strlen(text));
  if(rLen == 0) return;
  
  assertTrue(x < FRAME_WIDTH, "Text is too far right.");
  assertTrue(y < FRAME_HEIGHT, "Text is too low.");
  
  char_t c;
  uint16_t xPos = x;
  uint16_t yPos = y * FRAME_WIDTH;
  size_t i = 0;
  do {
    c = text[i++];
    if(c == '\n') {
      yPos += FRAME_WIDTH;
      xPos = x;
      continue;
    }

    assertTrue(xPos < FRAME_WIDTH, "Text overflows right.");
    
    FRAME_BUFFER[yPos + xPos] = c;
    FRAME_COLOR[yPos + xPos] = color;
    xPos++;
  } while(i < rLen);
}