/**
 * Copyright (c) 2024 Dominic Masters
 * 
 * This software is released under the MIT License.
 * https://opensource.org/licenses/MIT
 */

#pragma once
#include "dawn.h"

#define LANGUAGE_STRING_COUNT_MAX 128
#define LANGUAGE_STRING_KEY_LENGTH_MAX 64
#define LANGUAGE_STRING_LENGTH_MAX 1024

typedef struct {
  const char_t keys[LANGUAGE_STRING_COUNT_MAX][LANGUAGE_STRING_KEY_LENGTH_MAX];
  const char_t strings[LANGUAGE_STRING_COUNT_MAX][LANGUAGE_STRING_LENGTH_MAX];
  int32_t count;
} language_t;

extern language_t LANGUAGE;

/**
 * Initializes the language system.
 */
void languageInit();

/**
 * Gets the pointer to the language string for the given key. Pointer should not
 * be modified or freed.
 * 
 * @param key The key to get the string for.
 * @return The pointer to the string.
 */
const char_t * languageGetPointer(const char_t *key);

/**
 * Returns the language string for the given key.
 * 
 * @param buffer The buffer to write the string to, or NULL to get length.
 * @param key The key to get the string for.
 * @return The length of the string.
 */
int32_t languageGet(char_t *buffer, const char_t *key);