/**
 * Copyright (c) 2024 Dominic Masters
 * 
 * This software is released under the MIT License.
 * https://opensource.org/licenses/MIT
 */

#include "conversationinteractentity.h"
#include "assert/assert.h"
#include "rpg/entity/entity.h"
#include "locale/language.h"
#include "ui/textbox.h"

uint16_t conversationInteractEntityInit(
  conversation_t *convo,
  const uint16_t i
) {
  assertNotNull(convo, "Conversation is NULL!");
  assertNotNull(convo->data.entityInteract.entity, "Conversation user is NULL!");

  entity_t *e = (entity_t*)convo->data.entityInteract.entity;
  switch(e->type) {
    case ENTITY_TYPE_SIGN:
      textboxSetText("entities.sign.name", e->sign.texts[i]);
      return i;

    case ENTITY_TYPE_NPC:
      textboxSetText(e->npc.text.name, e->npc.text.text);
      return i;

    default:
      assertUnreachable("Invalid entity type for conversation.");
      return CONVERSATION_INVALID;
  }
}

uint16_t conversationInteractEntityUpdate(
  conversation_t *convo,
  const uint16_t i
) {
  assertNotNull(convo, "Conversation is NULL!");
  assertNotNull(convo->data.entityInteract.entity, "Conversation user is NULL!");

  entity_t *e = (entity_t*)convo->data.entityInteract.entity;
  switch(e->type) {
    case ENTITY_TYPE_SIGN:
      if(textboxIsOpen()) return CONVERSATION_CONTINUE;
      if(i == SIGN_TEXT_COUNT_MAX-1) return CONVERSATION_DONE;
      if(e->sign.texts[i+1][0] == '\0') return CONVERSATION_DONE;
      return CONVERSATION_NEXT;

    default:
      switch(i) {
        case 0:
          return textboxIsOpen() ? CONVERSATION_CONTINUE : CONVERSATION_DONE;
        
        default:
          return CONVERSATION_INVALID;
      }
  }
}