/**
 * Copyright (c) 2024 Dominic Masters
 * 
 * This software is released under the MIT License.
 * https://opensource.org/licenses/MIT
 */

#pragma once
#include "locale/language.h"

typedef struct {
  char_t name[LANGUAGE_STRING_KEY_LENGTH_MAX+1];
  char_t text[LANGUAGE_STRING_KEY_LENGTH_MAX+1];
} npctext_t;

typedef struct {
  uint8_t nothing;
} npcconversation_t;

typedef union {
  npctext_t text;
  npcconversation_t conversation;
} npc_t;

/**
 * Initializes an NPC.
 * 
 * @param npc NPC to initialize.
 */
void npcInit(npc_t *npc);

/**
 * Sets the name of an NPC.
 * 
 * @param npc NPC to set name for.
 * @param name Name to set.
 */
void npcNameSet(npc_t *npc, const char_t *name);

/**
 * Sets the text of an NPC.
 * 
 * @param npc NPC to set text for.
 * @param text Text to set.
 */
void npcTextSet(npc_t *npc, const char_t *text);