/**
 * Copyright (c) 2024 Dominic Masters
 * 
 * This software is released under the MIT License.
 * https://opensource.org/licenses/MIT
 */

#include "tile.h"
#include "assert/assert.h"
#include "game/time.h"

const char_t TILE_SYMBOLS[] = {
  ' ',// NULL
  '#',
  '/',
  ' ',
  '-',// BUILDING_WALL
  '/',
  ' ',
  '#',
  '=',// STAIRS
  'n',
  'I',
  '|',
  '-',// RAIL_SLEEPER
  '#',
  'i'
};

const uint8_t TILE_COLORS[] = {
  COLOR_BLACK,// NULL
  COLOR_GREEN,
  COLOR_BLUE,
  COLOR_MAGENTA,
  COLOR_GRAY,// BUILDING_WALL
  COLOR_BROWN,
  COLOR_BLACK,
  COLOR_GRAY,
  COLOR_GRAY, // STAIRS
  COLOR_BROWN,
  COLOR_WHITE,
  COLOR_GRAY,
  COLOR_BROWN,// RAIL_SLEEPER
  COLOR_RED,
  COLOR_YELLOW
};

char_t tileSymbolGet(const tile_t tile) {
  switch(tile) {
    case TILE_WATER:
      int32_t j = (int32_t)(TIME.time * 2) % 4;
      switch(j) {
        case 0: return '/';
        case 1: return '|';
        case 2: return '\\';
        case 3: return '|';
      }

    default:
      return TILE_SYMBOLS[tile];
  }
}

uint8_t tileColorGet(const tile_t tile) {
  switch(tile) {
    default:
      return TILE_COLORS[tile];
  }
}

bool_t tileIsSolid(const tile_t tile) {
  switch(tile) {
    case TILE_NULL:
    case TILE_WATER:
    case TILE_BUILDING_WALL:
    case TILE_ROOF:
    case TILE_RAILING:
    case TILE_COLUMN:
    case TILE_RAIL_SLEEPER:
    case TILE_RAIL_TRACK:
    case TILE_LAMP:
      return true;

      
    default:
      return false;
  }
  return false;
}