/**
 * Copyright (c) 2024 Dominic Masters
 * 
 * This software is released under the MIT License.
 * https://opensource.org/licenses/MIT
 */

#pragma once
#include "display/color.h"

typedef enum {
  TILE_NULL = 0,
  TILE_GRASS = 1,
  TILE_WATER = 2,

  TILE_BUILDING_WALL = 4,
  TILE_ROOF = 5,
  TILE_WALKABLE_NULL = 6,
  TILE_COBBLESTONE = 7,
  TILE_STAIRS = 8,
  TILE_RAILING = 9,
  TILE_COLUMN = 10,
  TILE_RAIL_TRACK = 11,
  TILE_RAIL_SLEEPER = 12,
  TILE_CARPET = 13,
  TILE_LAMP = 14
} tile_t;

extern const char_t TILE_SYMBOLS[];

/**
 * Returns the symbol used by the given tile.
 * 
 * @param tile Tile to get the symbol of.
 * @return The symbol for this tile.
 */
char_t tileSymbolGet(const tile_t tile);

/**
 * Returns the color used by a given tile.
 * 
 * @param tile Tile to get the color of.
 * @return The color of this tile.
 */
uint8_t tileColorGet(const tile_t tile);

/**
 * Returns whether or not the tile is solid.
 * 
 * @param tile Tile to check.
 * @return True if the tile is solid, false otherwise.
 */
bool_t tileIsSolid(const tile_t tile);