/**
 * Copyright (c) 2024 Dominic Masters
 * 
 * This software is released under the MIT License.
 * https://opensource.org/licenses/MIT
 */

#pragma once
#include "dawn.h"

extern uint64_t MEMORY_ALLOCATED;

/**
 * Allocates memory. Will assert fail if no memory is available.
 * 
 * @param size The size of the memory to allocate.
 * @return The allocated memory.
 */
void * memoryAllocate(const size_t size);

/**
 * Frees memory.
 * 
 * @param ptr The memory to free.
 */
void memoryFree(void *ptr);

/**
 * Reallocates memory. Will assert fail if no memory is available.
 * 
 * @param ptr The memory to reallocate.
 * @param size The new size of the memory.
 * @return The reallocated memory.
 */
void * memoryReallocate(void *ptr, const size_t size);

/**
 * Sets memory to a specific value.
 * 
 * @param ptr The memory to set.
 * @param value The value to set.
 * @param size The size of the memory to set.
 */
void memorySet(void *ptr, const uint8_t value, const size_t size);

/**
 * Copies memory from one location to another.
 * 
 * @param dest The destination memory.
 * @param src The source memory.
 * @param size The size of the memory to copy.
 */
void memoryCopy(void *dest, const void *src, const size_t size);

/**
 * Initializes the memory system.
 */
void memoryInit();

/**
 * Tests if there is any memory allocated.
 */
void memoryTestZero();